import { Server } from "socket.io";
import {TSocket} from "../utilities/Types";
import ZoneRepository from "../repositories/ZoneRepository";
import ZoneManager from "../ZoneManager";
import {Character, Zone} from "@prisma/client";

interface IZoneLoad {
    zoneId: number;
    name: string;
    width: number;
    height: number;
    tiles: number[][];
    walls: number[][];
}

/**
 * Handle game master zone save event
 * @param socket
 * @param io
 */
export default function (socket: TSocket, io: Server) {
    socket.on('gm:zone_editor:zone:save', async (data: IZoneLoad) => {
        console.log(`---GM ${socket.character?.id} has saved zone via zone editor.`);

        console.log(data);

        if (!data.zoneId) {
            console.log(`---Zone id not provided.`);
            return;
        }

        let zone = await ZoneRepository.getById(data.zoneId);

        if (!zone) {
            console.log(`---Zone not found.`);
            return;
        }

        await ZoneRepository.update(
            data.zoneId,
            data.name,
            data.width,
            data.height,
            data.tiles,
            data.walls
        );

        zone = await ZoneRepository.getById(data.zoneId);

        // send over zone and characters to socket
        socket.emit('gm:zone_editor:zone:load', zone);
    });
}